
CREATE TABLE events (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY_KEY,
    date VARCHAR(10) NOT NULL,
    description TEXT NOT NULL,
    user TEXT, 
);

CREATE todos (
    id INTEGER NOT NULL AUTO_INCREMENT PRIMARY_KEY,
    description TEXT NOT NULL
    user TEXT, 
);




